=========
Changelog
=========

Version 1.19.0
--------------


Version 1.18.0
--------------


Version 1.17.0
--------------


Version 1.16.2
--------------

- 50cdb54 Adding changelog for version 1.16.1
- 4023515 Adding changelog for version 1.16.0
- 582b9f7 Adding changelog for version 1.16.0
- 827ca4a Revert "Adding changelog for version 1.16.0"
- c783d01 Adding changelog for version 1.16.0
- 1b87173 Update CHANGELOG.rst
- 1300ef6 Adding changelog for version 1.16.0
- 01fdf6a Adding changelog for version 1.16.0
- 55e7db2 Adding changelog for version 1.16.0

Version 1.16.1
--------------


Version 1.16.0
--------------

- 582b9f7 Adding changelog for version 1.16.0
- 827ca4a Revert "Adding changelog for version 1.16.0"
- c783d01 Adding changelog for version 1.16.0
- 1b87173 Update CHANGELOG.rst
- 1300ef6 Adding changelog for version 1.16.0
- 01fdf6a Adding changelog for version 1.16.0
- 55e7db2 Adding changelog for version 1.16.0

Version 1.16.0
--------------

- 827ca4a Revert "Adding changelog for version 1.16.0"
- c783d01 Adding changelog for version 1.16.0
- 1b87173 Update CHANGELOG.rst
- 1300ef6 Adding changelog for version 1.16.0
- 01fdf6a Adding changelog for version 1.16.0
- 55e7db2 Adding changelog for version 1.16.0

Version 1.15.0
--------------


Version 1.14.0
--------------


Version 1.13.0
--------------

- 86d9196 Adding changelog for version 1.13.0

Version 1.13.0
--------------


Version 1.12.0
--------------


Version 1.11.0
--------------


Version 1.10.0
--------------


Version 1.9.0
-------------

- 37ce7e1 Update Eiffellib version to latest. (#10)

Version 1.8.0
-------------

- 96d02ae Make the logging module more configurable and easier to use (#9)

Version 1.7.0
-------------

- ecfbe47 Add default identifier
- 2b2eadc Adding a logging module to ETOS library (#8)

Version 1.6.0
-------------


Version 1.5.0
-------------


Version 1.4.0
-------------


Version 1.3.0
-------------


Version 1.2.0
-------------


Version 1.1.0
-------------

- f03b3e1 Update README.rst (#7)
- 7376a7e Add CODEOWNERS file with etos maintainers (#6)
- 19fa706 Update README.rst (#5)
